<?php
/**
 * @file
 * Hooks provided by the commerce_rma module.
 */

/**
 * Defines return reasons.
 *
 * The return reasons array structure is as follows:
 * - name: machine-name identifying the return reason using lowercase
 *   alphanumeric characters, -, and _.
 * - title: the translatable title of the return reason, used in administrative
 *   interfaces.
 * - description: a translatable description of the return reason itself, used
 *   in user interfaces.
 * - group: a translatable return reason group.
 * - weight: integer weight used for sorting lists of return reasons; defaults
 *   to 0.
 *
 * @return array
 *   An array of return reason keyed by name.
 */
function hook_commerce_rma_return_reasons_info() {

  $return_reasons = array();

  $return_reasons['wrong_product_received'] = array(
    'name' => 'wrong_product_received',
    'title' => t('Wrong product received'),
    'description' => t('The received product was not the one expected'),
    'group' => t('product'),
    'weight'      => -10,
  );

  $return_reasons['wrong_product_description'] = array(
    'name' => 'poor_product_description',
    'title' => t('Poor product description'),
    'description' => t("Product doesn't match online product description"),
    'group' => t('product'),
    'weight' => -9,
  );

  return $return_reasons;
}

/**
 * Allows you to alter return reasons.
 *
 * @param array $return_reasons
 *   Array of return reasons keyed by name exposed by
 *   hook_commerce_line_item_reasons_info() implementations.
 *
 * @see hook_commerce_rma_return_reasons_info()
 */
function hook_commerce_rma_return_reasons_info_alter(&$return_reasons) {
  // Alter the weight of a particular return reasons.
  if (!empty($return_reasons['wrong_product_description'])) {
    $return_reasons['wrong_product_description']['weight'] = 18;
  }
}

/**
 * Defines return statuses for line items attached to a return.
 *
 * The return statuses array structure is as follows:
 * - name: machine-name identifying the return status using lowercase
 *   alphanumeric characters, -, and _.
 * - title: the translatable title of the return status, used in administrative
 *   interfaces.
 * - description: a translatable description of the return status itself, used
 *   in user interfaces.
 * - weight: integer weight used for sorting lists of return status; defaults
 *   to 0.
 *
 * @return array
 *   An array of return status keyed by name.
 */
function hook_commerce_rma_return_statuses_info() {

  $statuses = array();

  $statuses['received_waiting_for_refund'] = array(
    'name' => 'received_waiting_for_refund',
    'title' => t('Received and waiting for refund'),
    'description' => t('The product was received back by the seller'),
    'weight' => -10,
  );

  $statuses['received_refunds_made'] = array(
    'name' => 'received_refunds_made',
    'title' => t('Received and refunds made'),
    'description' => t('The seller has found the products as refundable and paid back the client'),
    'weight' => -9,
  );

  return $statuses;
}

/**
 * Allows you to alter return statuses.
 *
 * @param array $statuses
 *   Array of return status keyed by name exposed by
 *   hook_commerce_line_item_return_status_info() implementations.
 *
 * @see hook_commerce_rma_return_statuses_info()
 */
function hook_commerce_rma_return_statuses_info_alter(&$statuses) {
  // Alter the weight of a particular return status.
  if (!empty($statuses['received_refunds_made'])) {
    $statuses['received_refunds_made']['weight'] = 10;
  }
}
