<?php
/**
 * @file
 * Functions to render user pages for commerce_rma module.
 */

/**
 * Implements hook_form().
 */
function commerce_rma_return_user_form($form, &$form_state, $commerce_order, $old_commerce_order_return = NULL) {
  // Ensure this include file is loaded when the form is rebuilt from the cache.
  $form_state['build_info']['files']['form'] = drupal_get_path('module', 'commerce_rma') . '/includes/commerce_rma.pages.inc';
  $form_state['#attached']['css'][] = drupal_get_path('module', 'commerce_rma') . '/theme/commerce_rma.theme.css';

  // Performs operation to transform $order object into
  // $commerce_order_return object.
  $commerce_order_return = commerce_rma_commerce_return_new($commerce_order);

  // Copy all properties from old return to the new one.
  if (!is_null($old_commerce_order_return)) {
    $properties = entity_get_property_info('commerce_order');

    foreach ($properties['bundles']['commerce_return']['properties'] as $name => $property) {
      if (property_exists($old_commerce_order_return, $name) && $name != 'commerce_line_items') {
        $commerce_order_return->$name = $old_commerce_order_return->$name;
      }
    }
  }

  // Ensure the owner name is accessible if the uid is set.
  if (!empty($commerce_order_return->uid) && $owner = user_load($commerce_order_return->uid)) {
    $commerce_order_return->name = $owner->name;

    if (empty($commerce_order_return->mail)) {
      $commerce_order_return->mail = $owner->mail;
    }
  }

  // If return is new, set the default status for customer.
  if (isset($commerce_order_return->is_new)) {
    $commerce_order_return->status = 'return_remove';
  }

  if (empty($commerce_order_return->created)) {
    $commerce_order_return->date = format_date(REQUEST_TIME, 'custom', 'Y-m-d H:i:s O');
  }

  // Add the field related form elements.
  $form_state['commerce_order_return'] = $commerce_order_return;
  field_attach_form('commerce_order', $commerce_order_return, $form, $form_state);

  // Hide the return total and order reference fields from direct editing.
  $form['commerce_order_total']['#access'] = FALSE;
  $form['commerce_order_reference']['#access'] = FALSE;

  $form['actions'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('form-return-actions')),
    '#weight' => 100,
  );

  // We add the form's #submit array to this button along with the actual submit
  // handler to preserve any submit handlers added by a form callback_wrapper.
  $submit = array();

  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  // Expose a cancel button.
  $form['actions']['cancel'] = array(
    '#type' => 'submit',
    '#executes_submit_callback' => TRUE,
    '#value' => t('Cancel return'),
    '#limit_validation_errors' => array(),
    '#submit' => array('commerce_rma_cancel_return_user_form_submit'),
  );

  // Expose a submit button.
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Next', array(), array('context' => 'a drupal commerce return')),
    '#submit' => array_merge($submit, array('commerce_rma_return_user_form_submit')),
  );

  // We append the validate handler to #validate in case a form callback_wrapper
  // is used to add validate handlers earlier.
  $form['#validate'][] = 'commerce_rma_return_user_form_validate';

  return $form;
}

/**
 * Implements hook_form_validate().
 */
function commerce_rma_return_user_form_validate($form, &$form_state) {

  $commerce_order_return = $form_state['commerce_order_return'];

  // Notify field widgets to validate their data.
  field_attach_form_validate('commerce_order', $commerce_order_return, $form, $form_state);
}

/**
 * Implements hook_form_submit().
 */
function commerce_rma_cancel_return_user_form_submit($form, &$form_state) {
  $commerce_order_return = $form_state['commerce_order_return'];

  $form_state['redirect'] = 'user/' . $commerce_order_return->uid . '/orders';
}

/**
 * Implements hook_form_submit().
 */
function commerce_rma_return_user_form_submit($form, &$form_state) {
  $commerce_order_return = $form_state['commerce_order_return'];

  // Notify field widgets.
  field_attach_submit('commerce_order', $commerce_order_return, $form, $form_state);

  // Ensure the attached customer profile is associated with the order owner
  // if it does not have a uid yet and the order does.
  $wrapper = entity_metadata_wrapper('commerce_order', $commerce_order_return);

  if (!is_null($wrapper->commerce_customer_rma->value()) && $wrapper->commerce_customer_rma->uid->value() == 0) {
    $wrapper->commerce_customer_rma->uid = $commerce_order_return->uid;
    $wrapper->commerce_customer_rma->save();
  }

  // Set the commerce_order_reference value.
  if (isset($commerce_order_return->is_new)) {
    $wrapped_return = entity_metadata_wrapper('commerce_order', $commerce_order_return);
    $wrapped_return->commerce_order_reference = $commerce_order_return->target_id;
  }

  // Save the return.
  commerce_order_save($commerce_order_return);

  // Ensure the attached line items are associated with the order if they do not
  // have an order_id set yet.
  foreach (entity_metadata_wrapper('commerce_order', $commerce_order_return)->commerce_line_items as $line_item_wrapper) {
    if ($line_item_wrapper->order_id->value() == 0) {
      $line_item_wrapper->order_id = $commerce_order_return->order_id;
      $line_item_wrapper->save();
    }
  }

  $form_state['redirect'] = array(
    'user/' . $commerce_order_return->uid . '/order/' . $commerce_order_return->target_id . '/returns/' .
    $commerce_order_return->order_id . '/confirmation',
  );
}

/**
 * Implements hook_form().
 */
function commerce_rma_confirmation_return_user_form($form, &$form_state, $commerce_order_return) {

  // Store the return object into the form_state array.
  $form_state['commerce_order_return'] = $commerce_order_return;

  $render = entity_view('commerce_order', array($commerce_order_return), 'customer', LANGUAGE_NONE, TRUE);

  // Hidding commerce_order_reference, useless for the customer.
  $render['commerce_order'][$commerce_order_return->order_id]['commerce_order_reference']['#access'] = FALSE;

  // We append the validate handler to #validate in case a form callback_wrapper
  // is used to add validate handlers earlier.
  $form['#validate'][] = 'commerce_rma_confirmation_return_user_form_validate';

  // Adding a confirmation checkbox.
  $form['confirmation'] = array(
    '#type' => 'checkbox',
    '#title' => t('Please, make sure you have selected the product(s) you want to return and also the right quantity for each product(s).'),
    '#default_value' => FALSE,
    '#return_value' => TRUE,
  );

  // We add the form's #submit array to this button along with the actual submit
  // handler to preserve any submit handlers added by a form callback_wrapper.
  $submit = array();

  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  $form['action'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('form-return-action-back')),
    '#weight' => 101,
  );

  $form['action']['back'] = array(
    '#type' => 'submit',
    '#executes_submit_callback' => TRUE,
    '#value' => t('Back'),
    '#limit_validation_errors' => array(),
    '#submit' => array('commerce_rma_redirect_return_user_form_submit'),
  );

  $form['action']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Confirm', array(), array('context' => 'a drupal commerce return')),
    '#submit' => array_merge($submit, array('commerce_rma_confirmation_return_user_form_submit')),
  );

  // Return the rendered elements and the form too.
  return $render + $form;
}

/**
 * Implements hook_form_validate().
 */
function commerce_rma_confirmation_return_user_form_validate($form, &$form_state) {
  if (empty($form_state['commerce_order_return'])
    || $form_state['commerce_order_return']->type != 'commerce_return'
  ) {
    form_set_error('return', t('This return is incorrect, please reload the page or contact the website administrator.'));
  }

  if (empty($form_state['values']['confirmation'])) {
    form_set_error('confirmation', t('You must check the confirmation checkbox to get through.'));
  }
}

/**
 * Implements hook_form_submit().
 */
function commerce_rma_confirmation_return_user_form_submit($form, &$form_state) {
  // Get the return object.
  $commerce_order_return = $form_state['commerce_order_return'];

  // Path to user return.
  $redirect = 'user/' . $commerce_order_return->uid . '/returns/' . $commerce_order_return->order_id;

  // Set the right status for the return.
  commerce_rma_status_update($commerce_order_return, 'return_processing', FALSE);

  // Invoke the related rule event.
  rules_invoke_all('commerce_order_return_is_created', $commerce_order_return);

  // Send a message to customer.
  drupal_set_message(
    t(
      '- Your request for return @number is confirmed.<br />- Please send the parcel with the products you would like to return.',
      array('@number' => $commerce_order_return->order_number)
    )
  );

  // Redirect to user returns.
  $form_state['redirect'] = $redirect;
}

/**
 * Implements hook_form_submit().
 */
function commerce_rma_redirect_return_user_form_submit($form, &$form_state) {
  $commerce_order_return = $form_state['commerce_order_return'];

  $return_wrapper = entity_metadata_wrapper('commerce_order', $commerce_order_return);
  $order = $return_wrapper->commerce_order_reference->value();

  // Go to the previous step.
  $form_state['redirect'] = 'user/' . $commerce_order_return->uid . '/order/' . $order->order_id . '/returns/add/' . $commerce_order_return->order_id;
}
