<?php
/**
 * @file
 * Area handler to display the empty text message for orders.
 */

class commerce_rma_handler_area_empty_text extends views_handler_area {
  /**
   * Set default handler options.
   *
   * return array
   *   Returns the default options.
   */
  public function option_definition() {
    $options = parent::option_definition();

    // Undefine the empty option.
    unset($options['empty']);

    // Define an option to link to orders list.
    $options['add_path'] = array('default' => 'admin/commerce/orders/list');

    return $options;
  }

  /**
   * Exposes a form to configure handler options.
   *
   * @param array $form
   *   The form array.
   * @param array $form_state
   *   The form state array.
   */
  public function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    // Don't display a form element for the undefined empty option.
    unset($form['empty']);

    $form['add_path'] = array(
      '#type' => 'textfield',
      '#title' => t('Path to orders list'),
      '#description' => t('Provide the path to orders list.'),
      '#default_value' => $this->options['add_path'],
    );
  }

  /**
   * Render the area.
   *
   * @param bool $empty
   *   Empty variable.
   *
   * @return string
   *   Return a default message when no returns found.
   */
  public function render($empty = FALSE) {
    // If the View contains exposed filter input, the empty message indicates
    // no orders matched the search criteria.
    $exposed_input = $this->view->get_exposed_input();

    if (!empty($exposed_input)) {
      return t('No returns match your search criteria.');
    }

    // Otherwise display the empty text indicating no returns have been created
    // yet and provide a link to the creation form if configured.
    if (!empty($this->options['add_path'])) {
      return t('No returns have been created yet. Go to <a href="!url">orders list</a> and create a return.', array('!url' => url($this->options['add_path'])));
    }
    else {
      return t('No returns have been created yet.');
    }
  }
}
