<?php
/**
 * @file
 * Defines an area handler that displays a "View return" form allowing the user
 * to enter an return number and redirect to that return's view page.
 */

class commerce_rma_handler_area_view_return_form extends views_handler_area {
  /**
   * Set default handler options.
   *
   * return array
   *   Returns the default options.
   */
  public function option_definition() {
    $options = parent::option_definition();

    // Undefine the empty option.
    unset($options['empty']);

    // Define an option to control the order identifier and redirect page.
    $options['identifier'] = array('default' => 'order_number');
    $options['redirect_page'] = array('default' => 'admin');

    return $options;
  }

  /**
   * Exposes a form to configure handler options.
   *
   * @param array $form
   *   The form array.
   * @param array $form_state
   *   The form state array.
   */
  public function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    // Don't display a form element for the undefined empty option.
    unset($form['empty']);

    $form['identifier'] = array(
      '#type' => 'radios',
      '#title' => t('Return identifier used for redirection'),
      '#options' => array(
        'order_number' => t('Return number', array(), array('context' => 'a drupal commerce return')),
        'order_id' => t('Return ID', array(), array('context' => 'a drupal commerce return')),
        'select' => t('Let the user select'),
      ),
      '#default_value' => $this->options['identifier'],
    );

    $form['redirect_page'] = array(
      '#type' => 'radios',
      '#title' => t('Redirect to which return view page'),
      '#options' => array(
        'admin' => t('Admin page'),
        'customer' => t('Customer page'),
        'select' => t('Let the user select'),
      ),
      '#default_value' => $this->options['redirect_page'],
    );
  }

  /**
   * Renders the "view return" form.
   *
   * @param bool $empty
   *   Empty variable.
   *
   * @return string
   *   Render the "view return" form.
   */
  public function render($empty = FALSE) {
    $form = drupal_get_form('commerce_rma_ui_redirect_form', $this->options['redirect_page'], $this->options['identifier']);
    return drupal_render($form);
  }
}
