<?php
/**
 * @file
 * Field handler to present a return product(s) link
 */

class commerce_rma_handler_field_order_return_link extends views_handler_field {
  /**
   * The class constructor.
   */
  public function construct() {
    parent::construct();
    $this->additional_fields['order_id'] = 'order_id';
    $this->additional_fields['uid'] = 'uid';
    $this->additional_fields['status'] = 'status';
  }

  /**
   * The query callback.
   */
  public function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  /**
   * Renders the "return products" link.
   *
   * @param array $values
   *   View's values.
   *
   * @return string
   *   The rendered link.
   */
  public function render($values) {
    $order_id = $this->get_value($values, 'order_id');
    $uid = $this->get_value($values, 'uid');
    $status = $this->get_value($values, 'status');

    // Get all commerce statuses.
    $statuses = commerce_order_statuses();

    // Ensure status exists in commerce statuses and it's equal to "completed".
    if (array_key_exists($status, $statuses) && commerce_rma_access('create', commerce_order_load($order_id))) {
      $text = !empty($this->options['text']) ? $this->options['text'] : t('Return products');
      $link = l($text, 'user/' . $uid . '/order/' . $order_id . '/returns/add');
    }
    else {
      $link = '';
    }

    return $link;
  }
}
