<?php
/**
 * @file
 * A plugin to handle access control based on custom access callback.
 * @package commerce_rma
 */

class views_plugin_access_rma extends views_plugin_access {
  /**
   * Initialize the plugin.
   *
   * @param object $view
   *   The view object.
   * @param object $display
   *   The display handler.
   */
  public function init(&$view, &$display) {
    $this->view = &$view;
    $this->display = &$display;
    $this->options = array();

    if (is_object($display->handler)) {
      $this->options = $display->handler->get_option('access');
    }
  }

  /**
   * Retrieve the default options.
   *
   * @param array $options
   *   Array storing view access options.
   */
  public function option_defaults(&$options) {
    $options['rma'] = array();

  }

  /**
   * Provide the default form for setting options.
   */
  public function options_form(&$form, &$form_state) {
  }

  /**
   * Provide the default form form for validating options.
   */
  public function options_validate(&$form, &$form_state) {
  }

  /**
   * Provide the default form form for submitting options.
   */
  public function options_submit(&$form, &$form_state) {
  }

  /**
   * Override summary_title().
   *
   * @return string
   *   A string to display as the clickable title for the access control.
   */
  public function summary_title() {
    return t('Rma Access function');
  }

  /**
   * Determine if the current user has access or not.
   *
   * @param object $account
   *   User account object.
   *
   * @return bool
   *   TRUE  => access is granted.
   *   FALSE => access isn't granted.
   */
  public function access($account) {
    return commerce_rma_access('view', NULL, NULL);
  }

  /**
   * Determine the access callback and arguments.
   *
   * This information will be embedded in the menu in order to reduce
   * performance hits during menu item access testing, which happens
   * a lot.
   *
   * @return array
   *   The first item should be the function to call,
   *   and the second item should be an array of arguments. The first
   *   item may also be TRUE (bool only) which will indicate no
   *   access control.
   */
  public function get_access_callback() {
    return array('commerce_rma_views_access', array(1));
  }
}
